//-------------------------------------------------------------------//
// BleederEffectSpawner                                              //
// this class handles the spawning of the bleeding effect on players //
//-------------------------------------------------------------------//

class BleederEffectSpawner extends Actor;

var float SpawnDelay;		// time between effect spawns
var float DelayLeft;		// time left until next spawn
var int NumSpawns;		// number of total effects to spawn
var int SpawnsLeft;		// number of effects left to spawn before the spawner is destroyed
var bool bIsSpawning;		// flag to check whether spawner is active
var vector RelLocation;		// the location of the spawner relative to the location of the owner
var class<Effects> EffectToSpawn;	// the effect we want to spawn

function StopSpawner()
{
	SetTimer(0.0, false);
	bIsSpawning = false;
}

function StartSpawner()
{
	// check if we're already spawning
	if (bIsSpawning)
	{
		// stop spawning and reset vars where pertinent
		StopSpawner();
		SpawnsLeft = NumSpawns;
	}
	bIsSpawning = true;
	SetTimer(SpawnDelay, true);
}

function SetRelativeLocation()
{
	RelLocation = Location - Owner.Location;
}

function InitSpawner()
{
	if (Location.Z != 0.0)
	{
		SetRelativeLocation();
	}
}

function SetSpawnProperties(optional float SD, optional int NS, optional int SL, optional class<Effects> E, optional bool RestartTimer)
{
	SpawnDelay = SD;
	NumSpawns = NS;
	SpawnsLeft = SL;
	EffectToSpawn = E;
	if (RestartTimer) StartSpawner();
	return;
}

function Timer()
{
	if (Owner != None)
	{
	// only process if we're spawning
 	  if (bIsSpawning)
	  {
		Spawn(EffectToSpawn, Self, , RelLocation + Owner.Location, Owner.Rotation);
		SpawnsLeft--;
		// we've run out of spawns
		if ((SpawnsLeft <= 0) || (Pawn(Owner).health >= Pawn(Owner).default.health) ||
			((SpawnsLeft > 60) && (Pawn(Owner).health <= 0)) || (SpawnsLeft >= 255))
		{
			StopSpawner();
			Destroy();
		}

	  }
	}
}

defaultproperties
{
     bHidden=True
}
